@@ -170,8 +170,31 @@ class TestWire(test_base.TestCase):
         r_port_name = "{}-openstack".format(constants.OVN_CLUSTER_ROUTER)
         options = {'router-port': r_port_name, 'arp_proxy': '172.16.0.0/16'}
 
-        wire._ensure_ovn_network_link(self.nb_idl, switch_name, 'internal',
-                                      provider_cidrs=provider_cidrs)
+        wire._ensure_ovn_network_link_internal(
+            self.nb_idl, switch_name, provider_cidrs)
+
+        self.nb_idl.lrp_add.assert_called_once_with(
+            constants.OVN_CLUSTER_ROUTER, r_port_name,
+            constants.OVN_CLUSTER_ROUTER_INTERNAL_MAC, provider_cidrs, peer=[],
+            may_exist=True)
+        m_ensure_lsp.assert_called_once_with(
+            self.nb_idl, mock.ANY, switch_name, 'router', 'router', **options)
+        self.nb_idl.lrp_set_gateway_chassis.assert_called_once_with(
+            r_port_name, CONF.local_ovn_cluster.bgp_chassis_id, 1)
+
+    @mock.patch.object(wire, '_execute_commands')
+    @mock.patch.object(wire, '_ensure_lsp_cmds')
+    def test__ensure_ovn_network_link_internal_multiple_cidrs(self,
+                                                              m_ensure_lsp,
+                                                              m_cmds):
+        switch_name = 'internal'
+        provider_cidrs = ['172.16.0.0/16', '192.0.2.0/24']
+        r_port_name = "{}-openstack".format(constants.OVN_CLUSTER_ROUTER)
+        options = {'router-port': r_port_name,
+                   'arp_proxy': '172.16.0.0/16 192.0.2.0/24'}
+
+        wire._ensure_ovn_network_link_internal(
+            self.nb_idl, switch_name, provider_cidrs)
 
         self.nb_idl.lrp_add.assert_called_once_with(
             constants.OVN_CLUSTER_ROUTER, r_port_name,
@@ -193,8 +216,8 @@ class TestWire(test_base.TestCase):
         self.nb_idl.lrp_add.side_effect = RuntimeError(
             'with different networks')
 
-        wire._ensure_ovn_network_link(self.nb_idl, switch_name, 'internal',
-                                      provider_cidrs=provider_cidrs)
+        wire._ensure_ovn_network_link_internal(
+            self.nb_idl, switch_name, provider_cidrs)
 
         self.nb_idl.lrp_add.assert_called_once_with(
             constants.OVN_CLUSTER_ROUTER, r_port_name,
@@ -207,16 +230,18 @@ class TestWire(test_base.TestCase):
         self.nb_idl.lrp_set_gateway_chassis.assert_called_once_with(
             r_port_name, CONF.local_ovn_cluster.bgp_chassis_id, 1)
 
+    @mock.patch.object(wire, '_execute_commands')
     @mock.patch.object(wire, '_ensure_lsp_cmds')
-    def test__ensure_ovn_network_link_external(self, m_ensure_lsp):
+    def test__ensure_ovn_network_link_external(
+            self, m_ensure_lsp, m_cmds):
         switch_name = 'external'
         ip = '1.1.1.2'
         mac = 'fake-map'
         r_port_name = "{}-{}".format(constants.OVN_CLUSTER_ROUTER, switch_name)
         options = {'router-port': r_port_name}
 
-        wire._ensure_ovn_network_link(self.nb_idl, switch_name, 'external',
-                                      ip=ip, mac=mac)
+        wire._ensure_ovn_network_link_external(
+            self.nb_idl, switch_name, ip, mac)
 
         self.nb_idl.lrp_add.assert_called_once_with(
             constants.OVN_CLUSTER_ROUTER, r_port_name,
@@ -247,10 +272,11 @@ class TestWire(test_base.TestCase):
     @mock.patch.object(wire, '_execute_commands')
     def test_ensure_ovn_routes(self, m_cmds):
         peer_ips = ['1.1.1.1']
-        wire._ensure_ovn_routes(self.nb_idl, peer_ips)
+        bfds = [test_utils.create_row(uuid='bfd')]
+        wire._ensure_ovn_routes(self.nb_idl, peer_ips, bfds)
         self.nb_idl.lr_route_add.assert_called_once_with(
             constants.OVN_CLUSTER_ROUTER, '0.0.0.0/0', peer_ips[0],
-            ecmp=True, may_exist=True)
+            ecmp=True, may_exist=True, bfd=bfds[0].uuid)
 
     @mock.patch.object(ovs_utils, 'ensure_flow')
     @mock.patch.object(linux_net, 'get_ip_version')
@@ -325,18 +351,27 @@ class TestWire(test_base.TestCase):
             self.sb_idl, self.bridge_mappings, ovs_flows, exposed_ips,
             routing_tables, routing_tables_routes)
 
-    def test_cleanup_wiring_ovn(self):
+    @mock.patch.object(linux_net, 'get_exposed_ips')
+    @mock.patch.object(linux_net, 'delete_exposed_ips')
+    def test_cleanup_wiring_ovn(self, _delete_exposed_ips, _get_exposed_ips):
         CONF.set_override('exposing_method', 'ovn')
         self.addCleanup(CONF.clear_override, 'exposing_method')
 
+        # Both IPs are present on the NIC but .42 is not expected
+        # to be exposed.
+        _get_exposed_ips.return_value = ['192.0.2.42', '192.0.2.24']
+
         ovs_flows = {}
-        exposed_ips = {}
+        exposed_ips = {
+            "fakels": {"192.0.2.24": {'bridge_device': "br-example"}}}
         routing_tables = {}
         routing_tables_routes = {}
-        ret = wire.cleanup_wiring(self.sb_idl, self.bridge_mappings, ovs_flows,
-                                  exposed_ips, routing_tables,
-                                  routing_tables_routes)
-        self.assertTrue(ret)
+        wire.cleanup_wiring(self.sb_idl, self.bridge_mappings, ovs_flows,
+                            exposed_ips, routing_tables,
+                            routing_tables_routes)
+        # Make sure we only delete the IP that isn't supposed to be exposed.
+        _delete_exposed_ips.assert_called_once_with({"192.0.2.42"},
+                                                    CONF.bgp_nic)
 
     def test_cleanup_wiring_evpn(self):
         CONF.set_override('exposing_method', 'vrf')
